@@ -340,7 +340,7 @@ def resource_attr_id_set(context, resource_id, atomic_key, attr_id):
         else:
             # Someone else set the attr_id first and/or we have a stale
             # view of the resource based on atomic_key, so delete the
-            # resource_properties_data (attr) db row.
+            # resource_properties_data (attr) DB row.
             LOG.debug('Not updating res_id %(rid)s with attr_id %(aid)s',
                       {'rid': resource_id, 'aid': attr_id})
             session.query(
@@ -657,7 +657,7 @@ def stack_get_all_by_root_owner_id(context, owner_id):
 
 
 def _get_sort_keys(sort_keys, mapping):
-    """Returns an array containing only whitelisted keys
+    """Returns an array containing only allowed keys
 
     :param sort_keys: an array of strings
     :param mapping: a mapping from keys to DB column names
@@ -692,7 +692,7 @@ def _paginate_query(context, query, model, limit=None, sort_keys=None,
     return query
 
 
-def _query_stack_get_all(context,  show_deleted=False,
+def _query_stack_get_all(context, show_deleted=False,
                          show_nested=False, show_hidden=False, tags=None,
                          tags_any=None, not_tags=None, not_tags_any=None):
     if show_nested:
@@ -769,11 +769,11 @@ def _filter_and_page_query(context, query, limit=None, sort_keys=None,
                     rpc_api.STACK_STATUS: models.Stack.status.key,
                     rpc_api.STACK_CREATION_TIME: models.Stack.created_at.key,
                     rpc_api.STACK_UPDATED_TIME: models.Stack.updated_at.key}
-    whitelisted_sort_keys = _get_sort_keys(sort_keys, sort_key_map)
+    valid_sort_keys = _get_sort_keys(sort_keys, sort_key_map)
 
     query = db_filters.exact_filter(query, models.Stack, filters)
     return _paginate_query(context, query, models.Stack, limit,
-                           whitelisted_sort_keys, marker, sort_dir)
+                           valid_sort_keys, marker, sort_dir)
 
 
 def stack_count_all(context, filters=None,
@@ -973,7 +973,7 @@ def user_creds_get(context, user_creds_id):
     db_result = context.session.query(models.UserCreds).get(user_creds_id)
     if db_result is None:
         return None
-    # Return a dict copy of db results, do not decrypt details into db_result
+    # Return a dict copy of DB results, do not decrypt details into db_result
     # or it can be committed back to the DB in decrypted form
     result = dict(db_result)
     del result['decrypt_method']
@@ -1058,12 +1058,12 @@ def _events_filter_and_page_query(context, query,
 
     sort_key_map = {rpc_api.EVENT_TIMESTAMP: models.Event.created_at.key,
                     rpc_api.EVENT_RES_TYPE: models.Event.resource_type.key}
-    whitelisted_sort_keys = _get_sort_keys(sort_keys, sort_key_map)
+    valid_sort_keys = _get_sort_keys(sort_keys, sort_key_map)
 
     query = db_filters.exact_filter(query, models.Event, filters)
 
     return _events_paginate_query(context, query, models.Event, limit,
-                                  whitelisted_sort_keys, marker, sort_dir)
+                                  valid_sort_keys, marker, sort_dir)
 
 
 def event_count_all_by_stack(context, stack_id):
@@ -1807,7 +1807,7 @@ def db_encrypt_parameters_and_properties(ctxt, encryption_key, batch_size=50,
     :param ctxt: RPC context
     :param encryption_key: key that will be used for parameter and property
                            encryption
-    :param batch_size: number of templates requested from db in each iteration.
+    :param batch_size: number of templates requested from DB in each iteration.
                        50 means that heat requests 50 templates, encrypt them
                        and proceed with next 50 items.
     :param verbose: log an INFO message when processing of each raw_template or
@@ -1831,7 +1831,7 @@ def db_decrypt_parameters_and_properties(ctxt, encryption_key, batch_size=50,
     :param ctxt: RPC context
     :param encryption_key: key that will be used for parameter and property
                            decryption
-    :param batch_size: number of templates requested from db in each iteration.
+    :param batch_size: number of templates requested from DB in each iteration.
                        50 means that heat requests 50 templates, encrypt them
                        and proceed with next 50 items.
     :param verbose: log an INFO message when processing of each raw_template or
@@ -1852,7 +1852,7 @@ def db_properties_data_migrate(ctxt, batch_size=50):
     """Migrate properties data from legacy columns to new location in db.
 
     :param ctxt: RPC context
-    :param batch_size: number of templates requested from db in each iteration.
+    :param batch_size: number of templates requested from DB in each iteration.
                        50 means that heat requests 50 templates, encrypt them
                        and proceed with next 50 items.
     """
