@@ -14,12 +14,11 @@
 import collections
 import copy
 import json
+from unittest import mock
 
 from cinderclient import exceptions as cinder_exp
-import mock
 from novaclient import exceptions as nova_exp
 from oslo_config import cfg
-import six
 
 from heat.common import exception
 from heat.common import template_format
@@ -120,7 +119,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
                                   self.t, stack, 'volume')
         self.assertEqual(
             "Property error: resources.volume.properties.size: "
-            "0 is out of range (min: 1, max: None)", six.text_type(error))
+            "0 is out of range (min: 1, max: None)", str(error))
 
     def test_cinder_create(self):
         fv = vt_base.FakeVolume('creating')
@@ -273,7 +272,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
                                   rsrc.FnGetAtt, 'unknown')
         self.assertEqual(
             'The Referenced Attribute (volume unknown) is incorrect.',
-            six.text_type(error))
+            str(error))
 
         self.cinder_fc.volumes.get.assert_called_with('vol-123')
 
@@ -359,7 +358,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         ex = self.assertRaises(exception.ResourceFailure, update_task)
         self.assertEqual('NotSupported: resources.volume: '
                          'Shrinking volume is not supported.',
-                         six.text_type(ex))
+                         str(ex))
 
         self.assertEqual((rsrc.UPDATE, rsrc.FAILED), rsrc.state)
 
@@ -409,7 +408,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
 
         update_task = scheduler.TaskRunner(rsrc.update, after)
         ex = self.assertRaises(exception.ResourceFailure, update_task)
-        self.assertIn('Over limit', six.text_type(ex))
+        self.assertIn('Over limit', str(ex))
 
         self.assertEqual((rsrc.UPDATE, rsrc.FAILED), rsrc.state)
         self.cinder_fc.volumes.extend.assert_called_once_with(fv.id, 2)
@@ -437,7 +436,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         update_task = scheduler.TaskRunner(rsrc.update, after)
         ex = self.assertRaises(exception.ResourceFailure, update_task)
         self.assertIn("Volume resize failed - Unknown status error_extending",
-                      six.text_type(ex))
+                      str(ex))
 
         self.assertEqual((rsrc.UPDATE, rsrc.FAILED), rsrc.state)
         self.cinder_fc.volumes.extend.assert_called_once_with(fv.id, 2)
@@ -599,7 +598,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         ex = self.assertRaises(exception.ResourceFailure, update_task)
         self.assertEqual((rsrc.UPDATE, rsrc.FAILED), rsrc.state)
         self.assertIn("NotSupported: resources.volume2: Shrinking volume is "
-                      "not supported", six.text_type(ex))
+                      "not supported", str(ex))
 
         props = copy.deepcopy(rsrc.properties.data)
         props['size'] = 3
@@ -1008,7 +1007,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         vp.update(combinations)
         rsrc = stack['volume2']
         ex = self.assertRaises(exc, rsrc.validate)
-        self.assertEqual(err_msg, six.text_type(ex))
+        self.assertEqual(err_msg, str(ex))
 
     def test_cinder_create_with_image_and_imageRef(self):
         self.stack_name = 'test_create_with_image_and_imageRef'
@@ -1022,7 +1021,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         vp.update(combinations)
         rsrc = stack.get('volume2')
         ex = self.assertRaises(exception.StackValidationFailed, rsrc.validate)
-        self.assertIn(err_msg, six.text_type(ex))
+        self.assertIn(err_msg, str(ex))
 
     def test_cinder_create_with_image_and_size(self):
         self.stack_name = 'test_create_with_image_and_size'
@@ -1253,7 +1252,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         vol.to_dict.return_value = vol_resp
         rsrc.client().volumes = mock.MagicMock()
         rsrc.client().volumes.get = mock.MagicMock(return_value=vol)
-        rsrc.client().volume_api_version = 2
+        rsrc.client().volume_api_version = 3
         rsrc.data = mock.MagicMock(return_value={'volume_type': 'lvmdriver-1'})
 
         reality = rsrc.get_live_state(rsrc.properties)
