@@ -15,14 +15,13 @@ import random
 import re
 import subprocess
 import time
+import urllib
 
 import fixtures
 from heatclient import exc as heat_exceptions
 from keystoneauth1 import exceptions as kc_exceptions
 from oslo_log import log as logging
 from oslo_utils import timeutils
-import six
-from six.moves import urllib
 from tempest import config
 import testscenarios
 import testtools
@@ -59,7 +58,7 @@ def call_until_true(duration, sleep_for, func, *args, **kwargs):
 
 
 def rand_name(name=''):
-    randbits = six.text_type(random.randint(1, 0x7fffffff))
+    randbits = str(random.randint(1, 0x7fffffff))
     if name:
         return name + '-' + randbits
     else:
@@ -104,8 +103,6 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
         self.identity_client = self.manager.identity_client
         self.orchestration_client = self.manager.orchestration_client
         self.compute_client = self.manager.compute_client
-        self.network_client = self.manager.network_client
-        self.volume_client = self.manager.volume_client
         self.object_client = self.manager.object_client
 
         self.client = self.orchestration_client
@@ -169,14 +166,6 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
     def _stack_rand_name(cls):
         return rand_name(cls.__name__)
 
-    def _get_network(self, net_name=None):
-        if net_name is None:
-            net_name = self.conf.fixed_network_name
-        networks = self.network_client.list_networks()
-        for net in networks['networks']:
-            if net['name'] == net_name:
-                return net
-
     def is_service_available(self, service_type):
         try:
             self.identity_client.get_endpoint_url(
@@ -483,7 +472,7 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
 
     def _get_nested_identifier(self, stack_identifier, res_name):
         rsrc = self.client.resources.get(stack_identifier, res_name)
-        nested_link = [l for l in rsrc.links if l['rel'] == 'nested']
+        nested_link = [lk for lk in rsrc.links if lk['rel'] == 'nested']
         nested_href = nested_link[0]['href']
         nested_id = nested_href.split('/')[-1]
         nested_identifier = '/'.join(nested_href.split('/')[-2:])
@@ -525,7 +514,7 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
                     if (filter_func(r) if callable(filter_func) else True))
 
     def get_resource_stack_id(self, r):
-        stack_link = [l for l in r.links if l.get('rel') == 'stack'][0]
+        stack_link = [lk for lk in r.links if lk.get('rel') == 'stack'][0]
         return stack_link['href'].split("/")[-1]
 
     def get_physical_resource_id(self, stack_identifier, resource_name):
